@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2010 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2011 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -9,10 +9,18 @@
 
 %currency_iso_orig =
   (
+   "CFA Franc BCEAO "      => "CFA Franc BCEAO",
+   "CFA Franc BEAC "       => "CFA Franc BEAC",
+   "Ngultrum "             => "Ngultrum",
+   "Unidades de fomento "  => "Unidades de fomento",
+   "Pa’anga"               => "Pa'anga",
+   "US Dollar (Next day) " => "US Dollar (Next day)",
+   "US Dollar (Same day) " => "US Dollar (Same day)",
   );
 
 %currency_iso_ignore =
   (
+    "XFU"  => 1,
     "XTS"  => 1,
     "XXX"  => 1,
   );
