@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2010 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2011 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -9,15 +9,18 @@
 
 %script_iso_orig =
   (
-   "Ethiopic (Ge\x{2bb}ez)"          => "Ethiopic (Geez)",
-   "Hangul (Hang\x{16d}l, Hangeul)"  => "Hangul (Hangul, Hangeul)",
-   "Hanunoo (Hanun\x{f3}o)"          => "Hanunoo (Hanunoo)",
-   "Lepcha (R\x{f3}ng)"              => "Lepcha (Rong)",
-   "Nakhi Geba ('Na-'Khi \x{b2}Gg\x{14f}-\x{b9}baw, Naxi Geba)" =>
+   "Ethiopic (Geʻez)"                => "Ethiopic (Geez)",
+   "Hangul (Hangŭl, Hangeul)"        => "Hangul (Hangul, Hangeul)",
+   "Hanunoo (Hanunóo)"               => "Hanunoo (Hanunoo)",
+   "Lepcha (Róng)"                   => "Lepcha (Rong)",
+   "Nakhi Geba ('Na-'Khi ²Ggŏ-¹baw, Naxi Geba)" =>
       "Nakhi Geba ('Na-'Khi Ggo-baw, Naxi Geba)",
-   "N\x{2019}Ko"                     => "N'Ko",
-   "Ol Chiki (Ol Cemet\x{2019}, Ol, Santali)" =>
+   "N’Ko"                            => "N'Ko",
+   "Nüshu"                           => "Nushu",
+   "Ol Chiki (Ol Cemet’, Ol, Santali)" =>
       "Ol Chiki (Ol Cemet, Ol, Santali)",
+   "Sharada, Śāradā"                  => "Sharada, Sarada",
+   "Takri, Ṭākrī, Ṭāṅkrī"              => "Takri, Takri, Tankri",
   );
 
 %script_iso_ignore =
